@@ -5,8 +5,8 @@
 ;; Author: Daniel Mendler <mail@daniel-mendler.de>
 ;; Maintainer: Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2022
-;; Version: 1.9
-;; Package-Requires: ((emacs "28.1") (org "9.5") (compat "30"))
+;; Version: 1.10
+;; Package-Requires: ((emacs "29.1") (org "9.6") (compat "30"))
 ;; URL: https://github.com/minad/org-modern
 ;; Keywords: outlines, hypermedia, text
 
@@ -742,7 +742,7 @@ whole buffer; otherwise, for the line at point."
      `(("^[ \t]*-\\{5,\\}$" 0
         '(face org-modern-horizontal-rule display
                ,(if (eq org-modern-horizontal-rule t)
-                    '(space :width text)
+                    '(space :width (- text 1))
                   org-modern-horizontal-rule)))))
    (when org-modern-table
      '(("^[ \t]*\\(|.*|\\)[ \t]*$" (0 (org-modern--table)))))
